@@ -1,15 +1,16 @@
 import asyncio
+from abc import ABCMeta, abstractmethod
 from typing import Any, Awaitable, Dict, Optional, Set, Tuple
 
 from ..context import Context, get_context
 from ..utils import cancel_tasks
 
 
-class ServiceMeta(type):
+class ServiceMeta(ABCMeta):
     def __new__(
         cls, name: str, bases: Tuple, namespace: Dict, **kwds: Any
     ) -> Any:
-        instance = type.__new__(
+        instance = super().__new__(
             cls, name, bases, dict(namespace),
         )
 
@@ -37,6 +38,8 @@ class Service(metaclass=ServiceMeta):
     __async_required__: Tuple[str, ...] = ("start", "stop")
     __required__: Tuple[str, ...] = ()
 
+    __instance_params: Dict[str, Any]
+
     def __init__(self, **kwargs: Any):
         lost_kw = self.__required__ - kwargs.keys()
         if lost_kw:
@@ -65,9 +68,18 @@ class Service(metaclass=ServiceMeta):
         self.__start_event = asyncio.Event()
 
     def _set_params(self, **kwargs: Any) -> None:
+        self.__instance_params = kwargs
+
         for name, value in kwargs.items():
             setattr(self, name, value)
 
+    def __getstate__(self) -> Dict[str, Any]:
+        return self.__instance_params
+
+    def __setstate__(self, state: Dict[str, Any]) -> None:
+        self._set_params(**state)
+
+    @abstractmethod
     async def start(self) -> Any:
         raise NotImplementedError
 
@@ -87,6 +99,7 @@ class SimpleServer(Service):
         task.add_done_callback(self.tasks.remove)
         return task
 
+    @abstractmethod
     async def start(self) -> None:
         raise NotImplementedError
 
